@@ -61,21 +61,73 @@ class Stream(object):
     def readInt(self):
         return struct.unpack(self.endian + "i", self.read(4))[0]
 
+    def readIntAt(self, pos):
+        current = self.tell()
+        self.seek(pos)
+        ret = self.readInt()
+        self.seek(current)
+        return ret
+
     def readUInt(self):
         return struct.unpack(self.endian + "I", self.read(4))[0]
 
+    def readUIntAt(self, pos):
+        current = self.tell()
+        self.seek(pos)
+        ret = self.readUInt()
+        self.seek(current)
+        return ret
+
+    def readFloat(self):
+        return struct.unpack(self.endian + "f", self.read(4))[0]
+
+    def readFloatAt(self, pos):
+        current = self.tell()
+        self.seek(pos)
+        ret = self.readFloat()
+        self.seek(current)
+        return ret
+
     def readShort(self):
         return struct.unpack(self.endian + "h", self.read(2))[0]
 
+    def readShortAt(self, pos):
+        current = self.tell()
+        self.seek(pos)
+        ret = self.readShort()
+        self.seek(current)
+        return ret
+
     def readUShort(self):
         return struct.unpack(self.endian + "H", self.read(2))[0]
 
+    def readUShortAt(self, pos):
+        current = self.tell()
+        self.seek(pos)
+        ret = self.readUShort()
+        self.seek(current)
+        return ret
+
     def readByte(self):
         return struct.unpack("B", self.read(1))[0]
 
+    def readByteAt(self, pos):
+        current = self.tell()
+        self.seek(pos)
+        ret = self.readByte()
+        self.seek(current)
+        return ret
+
     def readSByte(self):
         return struct.unpack("b", self.read(1))[0]
 
+    def readSByteAt(self, pos):
+        current = self.tell()
+        self.seek(pos)
+        ret = self.readSByte()
+        self.seek(current)
+        return ret
+
     def readHalf(self):
         if self.half is None:
             self.half = self.readByte()
@@ -137,6 +189,15 @@ class Stream(object):
         self.writeUInt(num)
         self.seek(current)
 
+    def writeFloat(self, num):
+        self.f.write(struct.pack(self.endian + "f", num))
+
+    def writeFloatAt(self, pos, num):
+        current = self.tell()
+        self.seek(pos)
+        self.writeFloat(num)
+        self.seek(current)
+
     def writeShort(self, num):
         self.f.write(struct.pack(self.endian + "h", num))
 
@@ -309,32 +370,34 @@ def getSectionNames(f):
         for line in f:
             line = line.rstrip("\r\n").replace("\ufeff", "")
             if line.startswith("!FILE:"):
-                ret.append(line[6:])
+                ret.append(line[6:].split("#")[0])
     except UnicodeDecodeError:
         return ret
     return ret
 
 
-def getSection(f, title, comment="#", fixchars=[]):
+def getSection(f, title, comment="#", fixchars=[], justone=True):
     ret = {}
     found = title == ""
     try:
         f.seek(0)
         for line in f:
             line = line.rstrip("\r\n").replace("\ufeff", "")
+            if found and line.startswith("!FILE:"):
+                if not justone:
+                    found = False
+                else:
+                    break
             if not found and line.startswith("!FILE:" + title):
                 found = True
-            elif found:
-                if title != "" and line.startswith("!FILE:"):
-                    break
-                elif line.find("=") > 0:
-                    split = line.split("=", 1)
-                    split[1] = split[1].split(comment)[0]
-                    if split[0] not in ret:
-                        ret[split[0]] = []
-                    for fixchar in fixchars:
-                        split[1] = split[1].replace(fixchar[0], fixchar[1])
-                    ret[split[0]].append(split[1])
+            elif found and line.find("=") > 0:
+                split = line.split("=", 1)
+                split[1] = split[1].split(comment)[0]
+                if split[0] not in ret:
+                    ret[split[0]] = []
+                for fixchar in fixchars:
+                    split[1] = split[1].replace(fixchar[0], fixchar[1])
+                ret[split[0]].append(split[1])
     except UnicodeDecodeError:
         return ret
     return ret
